@@ -127,10 +127,10 @@ class TradeUpdate:
         while True:
             self.insert_symbol()
             if t % 100 == 0:
-                self.insert_data(trade=True, kline=True)
+                self.insert_data(trade=False, kline=True)
                 self.auto_save()
             else:
-                self.insert_data(trade=True, kline=False)
+                self.insert_data(trade=False, kline=False)
                 time.sleep(120)
             t += 1
 
