@@ -7,7 +7,11 @@ class Response:
         self.data = dict_data.get('data', [])
         self.dict_data = dict_data
         if self.data is not None and len(self.data) > 0:
-            self.data = pd.DataFrame(self.data)
+            try:
+                self.data = pd.DataFrame(self.data)
+            except Exception as e:
+                print(e)
 
     def __str__(self):
-        return "{} {}".format(self.code, len(self.data))
+        #return "{} {}".format(self.code, len(self.data))
+        ret
